/***************************************************************************
 *   Copyright (C) 2004 by Fabian Vilers                                   *
 *   fabian@vilers.net                                                     *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifndef GENERATOR_H
#define GENERATOR_H

class QString;

#include "passwordcreatorform.h"

const QString VERSION = "1.1.2";
const QString numbers = "0123456789";
const QString vowels = "aeiouy";
const QString consonants = "bcdfghjklmnpqrstvwxz";
const QString characters = vowels + consonants;
const QString signs = "&@#'()!{}-_[]$*%,?;.:=+<>";
const int VOWEL = 1;
const int CONSONANT = 2;

class PasswordCreator : public PasswordCreatorForm
{
    Q_OBJECT

public:
    PasswordCreator(QWidget *parent = 0, const char *name = 0, WFlags fl = 0);
    ~PasswordCreator();

public slots:
    virtual void generateButton_clicked();
    virtual void fileCheck_toggled(bool state);
    virtual void specificCheck_toggled(bool state);
    virtual void clearButton_clicked();
    virtual void clipboardButton_clicked();
    virtual void customRadio_toggled(bool state);
    virtual void fileExit();
    virtual void helpAbout();
    virtual void specificExcludeCheck_toggled(bool state);
    
protected slots:
    virtual void closeEvent(QCloseEvent *e);

private:
    QString makePassword(int length, bool withNumbers, bool withLowercase, bool withUppercase, bool withSigns, QString exclude = "", QString specific = "", QString file = "");
    int evaluateQuality(QString password);
    QString makePronouncable(int length, QString exclude);
    QString removeExcluded(QString source, QString exclude);
    QString protect(QString source);
};

#endif

